@@ -2,7 +2,7 @@ package Perinci::Sub::To::Text::I18N;
 
 use parent 'Perinci::Sub::To::FuncBase::I18N';
 
-our $VERSION = '0.28'; # VERSION
+our $VERSION = '0.29'; # VERSION
 
 1;
 # ABSTRACT: Project class for Perinci::Sub::To::Text
@@ -11,7 +11,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -19,7 +19,7 @@ Perinci::Sub::To::Text::I18N - Project class for Perinci::Sub::To::Text
 
 =head1 VERSION
 
-version 0.28
+version 0.29
 
 =head1 HOMEPAGE
 
@@ -31,8 +31,7 @@ Source repository is at L<https://github.com/sharyanto/perl-Perinci-Sub-To-Text>
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website
-http://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-Sub-To-Text
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-Sub-To-Text>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
